Documentation
¶
Index ¶
- func FetchAllSTHs()
- func FetchEndpointUptimes()
- func Get4xxBackoff(submissionURL string) (time.Duration, string, int)
- func Get5xxBackoff(submissionURL string) (time.Duration, string, int)
- func GetAvgResponseTime(submissionURL string) (time.Duration, bool)
- func GetBadResponseBackoff(submissionURL string) (time.Duration, string)
- func GetEndpointUptime24h(submissionURL, endpoint string) (float64, bool)
- func GetEndpointUptime90d(submissionURL, endpoint string) (float64, bool)
- func GetRecentOutcomeCounts(submissionURL string) (successes, failures int)
- func GetSlowResponseBackoff(submissionURL string) (time.Duration, string)
- func GetTimeoutBackoff(submissionURL string) (time.Duration, string)
- func Record4xxResponse(submissionURL string, httpResponse *http.Response) bool
- func Record5xxResponse(submissionURL string, httpResponse *http.Response) bool
- func RecordBadResponse(submissionURL string) bool
- func RecordSlowResponse(submissionURL string) bool
- func RecordSubmissionOutcome(submissionURL string, outcome string)
- func RecordSubmissionResponseTime(submissionURL string, d time.Duration)
- func RecordTimeout(submissionURL string) bool
- func STHMonitor(ctx context.Context)
- func UptimeFetcher(ctx context.Context)
- type EndpointUptimes
- type STHData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FetchAllSTHs ¶
func FetchAllSTHs()
func FetchEndpointUptimes ¶
func FetchEndpointUptimes()
func GetAvgResponseTime ¶
GetAvgResponseTime returns the average response time over the last 30s for a log.
func GetBadResponseBackoff ¶
func GetEndpointUptime24h ¶
func GetEndpointUptime90d ¶
func GetRecentOutcomeCounts ¶
GetRecentOutcomeCounts returns the number of successful and failed responses in the last 30s.
func GetSlowResponseBackoff ¶
func Record4xxResponse ¶
func Record5xxResponse ¶
func RecordBadResponse ¶
func RecordSlowResponse ¶
func RecordSubmissionOutcome ¶
RecordSubmissionOutcome increments the Prometheus counter for a submission outcome.
func RecordSubmissionResponseTime ¶
RecordSubmissionResponseTime observes a response time for the given log.
func RecordTimeout ¶
func STHMonitor ¶
func UptimeFetcher ¶
Types ¶
type EndpointUptimes ¶
Click to show internal directories.
Click to hide internal directories.